Learn R Programming

SmithWilsonYieldCurve (version 1.0.1)

fFitSmithWilsonYieldCurve: Construct the Smith-Wilson yield curve

Description

Constructs the SmithWilson ZCB function based on the given market inputs and parameter choices

Usage

fFitSmithWilsonYieldCurve(TimesVector, CashflowMatrix, MarketValueVector, ufr, alpha)

Arguments

TimesVector
A vector of all cashflow times
CashflowMatrix
A matrix of all cashflows, instruments in rows, times in columns
MarketValueVector
A vector of market values of the insturments
ufr
The Ultimate Forward Rate (UFR) of the Smith-Wilson kernel
alpha
The rate of reversion of forward rates to the UFR in the Smith-Wilson kernel

Value

a list containing:
  • "P" a function of time which gives the ZCB price to that term
  • "xi" the vector of weights applied to the kernel functions to obtain the ZCB price
  • "K" the (compound) kernel vector